==> RsCMPX_Gprf-4.0.172.tar.gz: RsCMPX_Gprf-4.0.172/RsCMPX_Gprf/Implementations/Route/LteDl/Measurement/Spath.py <==
from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SpathCls:
	"""Spath commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("spath", core, parent)

	def get_count(self) -> int:
		"""SCPI: ROUTe:LTEDl:MEASurement<Instance>:SPATh:COUNt \n
		Snippet: value: int = driver.route.lteDl.measurement.spath.get_count() \n
		No command help available \n
			:return: signal_path_count: No help available
		"""
		response = self._core.io.query_str('ROUTe:LTEDl:MEASurement<Instance>:SPATh:COUNt?')
		return Conversions.str_to_int(response)

	def get_value(self) -> List[str]:
		"""SCPI: ROUTe:LTEDl:MEASurement<Instance>:SPATh \n
		Snippet: value: List[str] = driver.route.lteDl.measurement.spath.get_value() \n
		No command help available \n
			:return: signal_path: No help available
		"""
		response = self._core.io.query_str('ROUTe:LTEDl:MEASurement<Instance>:SPATh?')
		return Conversions.str_to_str_list(response)

	def set_value(self, signal_path: List[str]) -> None:
		"""SCPI: ROUTe:LTEDl:MEASurement<Instance>:SPATh \n
		Snippet: driver.route.lteDl.measurement.spath.set_value(signal_path = ['1', '2', '3']) \n
		No command help available \n
			:param signal_path: No help available
		"""
		param = Conversions.list_to_csv_quoted_str(signal_path)
		self._core.io.write(f'ROUTe:LTEDl:MEASurement<Instance>:SPATh {param}')

==> RsCMPX_Gprf-5.0.20.tar.gz: RsCMPX_Gprf-5.0.20/RsCMPX_Gprf/Implementations/Route/LteDl/Measurement/Spath.py <==
from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SpathCls:
	"""Spath commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("spath", core, parent)

	def get_count(self) -> int:
		"""SCPI: ROUTe:LTEDl:MEASurement<Instance>:SPATh:COUNt \n
		Snippet: value: int = driver.route.lteDl.measurement.spath.get_count() \n
		No command help available \n
			:return: signal_path_count: No help available
		"""
		response = self._core.io.query_str('ROUTe:LTEDl:MEASurement<Instance>:SPATh:COUNt?')
		return Conversions.str_to_int(response)

	def get_value(self) -> List[str]:
		"""SCPI: ROUTe:LTEDl:MEASurement<Instance>:SPATh \n
		Snippet: value: List[str] = driver.route.lteDl.measurement.spath.get_value() \n
		No command help available \n
			:return: signal_path: No help available
		"""
		response = self._core.io.query_str('ROUTe:LTEDl:MEASurement<Instance>:SPATh?')
		return Conversions.str_to_str_list(response)

	def set_value(self, signal_path: List[str]) -> None:
		"""SCPI: ROUTe:LTEDl:MEASurement<Instance>:SPATh \n
		Snippet: driver.route.lteDl.measurement.spath.set_value(signal_path = ['abc1', 'abc2', 'abc3']) \n
		No command help available \n
			:param signal_path: No help available
		"""
		param = Conversions.list_to_csv_quoted_str(signal_path)
		self._core.io.write(f'ROUTe:LTEDl:MEASurement<Instance>:SPATh {param}')
